# Experimaestro Information Retrieval (rust library)

This package contains implementations in Rust of several key components of the Experimaestro IR library:

- Sparse indexing: given a list of (term/impact) for each document, build/query an efficient structure